@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-09-30'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-10-03'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -131,7 +131,7 @@ Currently it only supports a subset of features compared to other
 * and so on.
 
 As an alternative to this module, if you are looking to reduce dependencies, you
-might also want to try using `fatten` to fatpack your
+might also want to try using `depak` to fatpack/datapack your
 `Perinci::CmdLine::Lite`-based script.
 
 TODO:
@@ -687,7 +687,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.27 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-30.
+This document describes version 0.28 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-10-03.
 
 =head1 SYNOPSIS
 
@@ -756,7 +756,7 @@ for parsing YAML).
 =back
 
 As an alternative to this module, if you are looking to reduce dependencies, you
-might also want to try using C<fatten> to fatpack your
+might also want to try using C<depak> to fatpack/datapack your
 C<Perinci::CmdLine::Lite>-based script.
 
 TODO:
